@@ -81,10 +81,10 @@ class Permission(Record):
     timeseriesID: str
     algorithmID: Optional[str]
     owner: str
-    reader: str
     status: PermissionStatus
     executionCount: int
     maxExecutionCount: Optional[int]
+    requestor: str
 
 
 class Result(Record):
@@ -99,11 +99,14 @@ Index(Execution, "owner")
 Index(Permission, "owner")
 Index(Timeseries, "owner")
 
-# index to fetch permissions by timeseriesID and reader
-Index(Permission, ["reader", "timeseriesID", "status"])
+# index to fetch permissions by timeseriesID and requestor
+Index(Permission, ["requestor", "timeseriesID", "status"])
 Index(Permission, "id_hash")
 Index(Permission, "status")
-Index(Dataset, "id_hash")
+Index(Execution, "datasetID")
+Index(Dataset, "timeseriesIDs")
 
 # index to fetch execution by the status
 Index(Execution, "status")
+Index(Permission, "timeseriesID")
+Index(Permission, ["timeseriesID", "requestor"])
